"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Scrubs = void 0;
var deepmerge_1 = __importDefault(require("deepmerge"));
var types_1 = require("@nofrills/types");
var Logger_1 = __importDefault(require("./Logger"));
var defaults = {
    properties: ['apikey', 'api-key', 'api_key', 'pass', 'password', 'secret', 'x-api-key'],
    text: '<secured>',
};
var Scrubs = /** @class */ (function () {
    function Scrubs(options) {
        if (options === void 0) { options = {}; }
        this.log = Logger_1.default;
        this.options = deepmerge_1.default.all([defaults, options]);
        this.registry = new Map();
    }
    Scrubs.prototype.clear = function (type) {
        this.registry.set(type, []);
        return this;
    };
    Scrubs.prototype.get = function (type) {
        this.log.debug('get', type);
        return this.registry.get(type);
    };
    Scrubs.prototype.properties = function (names) {
        this.options.properties = this.options.properties.slice().concat(names);
    };
    Scrubs.prototype.register = function (type, scrubber) {
        this.log.debug('register', type);
        var scrubbers = this.registry.get(type);
        if (scrubbers) {
            scrubbers.push(scrubber);
            this.registry.set(type, scrubbers);
        }
        else {
            this.registry.set(type, [scrubber]);
        }
        return this;
    };
    Scrubs.prototype.scrub = function (value, type) {
        var _this = this;
        if (value) {
            var typedef = type || types_1.Types.from(value);
            this.log.debug("scrub.pre:" + typedef, value);
            return (this.registry.get(typedef) || [])
                .reverse()
                .reduce(function (previous, scrubber) { return scrubber(previous, _this.options, _this); }, value);
        }
        return value;
    };
    return Scrubs;
}());
exports.Scrubs = Scrubs;
//# sourceMappingURL=Scrubs.js.map